% show the table Req's for HAMs 4&5
% BTL, April 2010

clear
close all

orange = [1   0.6   0];  % the color of the HAM req
purple = [0.5  0   0.8];
print_figs = false;
set(0,'DefaultAxesFontSize',22)
freq = logspace(-1, 2, 500);


%%
%HLTS_path = '/Users/BTL/Brians_files/Suspensions/HLTS_Mar2010_forFDR/HLTS_Mar_2010/';
HLTS_path = './';
HLTS_file = 'HLTS_model_damped';
load([HLTS_path, HLTS_file])


HLTS_freqresp = freqresp(HLTS_model, 2*pi*freq);

xHLTS_TF = abs(squeeze(HLTS_freqresp(out.long_mirror, in.long_gnd, :)));
zHLTS_TF = abs(squeeze(HLTS_freqresp(out.vert_mirror, in.vert_gnd, :)));

HLTS_transmission_fig = figure;
ll=loglog(...
    freq,abs(xHLTS_TF),...
    freq,1e-3 * abs(zHLTS_TF));
set(ll,'LineWidth',2)

title('Transmission of the HAM Large Triple Suspension','FontSize',24)

leg = legend(...
    'longitudinal HAM table to longitudinal mirror',...
    '1/1000 * vertical HAM table to vertical mirror',...
    'Location','SouthWest');
%set(leg,'FontSize',16)
grid on
axis([ 5 100 1e-9 1e-4])
set(gca,'YTick',logspace(-9, 2, 12))
xlabel('Freq (Hz)')
ylabel('transmission mag (m/m)')

FillPage('w');
IDfig;


%%
%HSTS_path = '/Users/BTL/Brians_files/Suspensions/HSTS_Oct09_without_extras/';
HSTS_path = './';
HSTS_file = 'HSTS_model_damped';
load([HSTS_path, HSTS_file])

HSTS_freqresp = freqresp(HSTS_model, 2*pi*freq);

xHSTS_TF = abs(squeeze(HSTS_freqresp(out.long_mirror, in.long_gnd, :)));
zHSTS_TF = abs(squeeze(HSTS_freqresp(out.vert_mirror, in.vert_gnd, :)));

HSTS_transmission_fig = figure;
ll=loglog(...
    freq,abs(xHSTS_TF),...
    freq,1e-3 * abs(zHSTS_TF));
set(ll,'LineWidth',2)

title('Transmission of the HAM Small Triple Suspension','FontSize',24)

leg = legend(...
    'longitudinal HAM table to longitudinal mirror',...
    '1/1000 * vertical HAM table to vertical mirror',...
    'Location','SouthWest');
%set(leg,'FontSize',16)
grid on
axis([ 5 100 1e-9 1e-4])
set(gca,'YTick',logspace(-9, 2, 12))
xlabel('Freq (Hz)')
ylabel('transmission mag (m/m)')

FillPage('w');
IDfig;

% it is asserted in T080192 that
% xSRCL = sqrt(xHLTS^2 + (2*xHLTS)^2 + (2*HSTS)^2);
% is is further asserted in T0900435, the HSTS FDR, that near 10 Hz, xHLTS = xHSTS
% so xSRCL = sqrt(9) * xHLTS

% we want HAM motion such that
% xSRCL_req = 3 * xHLTS_TF * HAM_target
%    or
% HAM_target = xSRCL_req /( 3 * xHLTS_TF)
%%

%SRM_thermal_freq = [  5,       30,    100,];
%SRM_thermal_data = [1.7e-16, 2e-18,  2e-18];
DARM_cont_freq = [ 10,      10.6,   11.3,    12.1,   20];
DARM_cont_data = [5.9e-19, 3.6e-19, 2.6e-19, 2e-19, 7.8e-21];

SCRL_cont_data = DARM_cont_data * (1/6e-3) .* (DARM_cont_freq/10).^2;

disp('The SCRL specs are')
disp(SCRL_cont_data)

logreqnoise  = interp1(log10(DARM_cont_freq),log10(SCRL_cont_data),log10(freq));
SCRL_new_spec  = 10.^logreqnoise;

figure
loglog(DARM_cont_freq, DARM_cont_data, freq, SCRL_new_spec);
axis([9 40 1e-21 1e-16])
grid on

HAM_target = SCRL_new_spec' ./ (sqrt(abs(xHLTS_TF).^2 + (2*abs(xHLTS_TF)).^2 + (2*abs(xHSTS_TF)).^2));

x_SUS_TF = sqrt(abs(xHLTS_TF + 2*xHLTS_TF).^2 + (abs(2 * xHSTS_TF)).^2);
z_SUS_TF = 1e-3 * sqrt(abs(zHLTS_TF + 2* zHLTS_TF).^2 + (abs(2*zHSTS_TF)).^2);

%%
index_10Hz = find(freq>=10,1,'first');
x_SUS_TF_10Hz = x_SUS_TF(index_10Hz);
orig_SCRL_target_10Hz = 3e-17;
orig_HAM_target_10Hz = orig_SCRL_target_10Hz / x_SUS_TF_10Hz;
disp(['to make 3e-17, the HAM-ISI would have to be ',num2str( orig_HAM_target_10Hz)])
%%
[original_HAM_spec,SRM_HAM_horz_spec, SRM_HAM_vert_spec] = HAM_req(freq);

contribution_fig = figure;
ll=loglog(DARM_cont_freq, SCRL_cont_data, 'b-o',...
    freq, SRM_HAM_horz_spec .* x_SUS_TF','b',...
    freq, SRM_HAM_vert_spec .* z_SUS_TF','g',...
    freq, sqrt((SRM_HAM_horz_spec .* x_SUS_TF').^2 + (SRM_HAM_vert_spec .* z_SUS_TF').^2),'k--');
axis([9 40 1e-19 2e-16])
set(gca,'XTick',[9 10 15 20 25 30 35 40])
grid on
set(ll,'LineWidth',2);
set(ll(1),'Color',purple,'MarkerSize',6)
set(ll(3),'Color',[0 .7 0])
xlabel('freq (Hz)')
ylabel('ASD of SRCL cavity length (m/\surdHz)')
title('Contributions to the Signal Recycling Cavity Length','FontSize',24)
leg = legend('SRCL length target',...
    'Contribution from the HAM-ISI horizontal SRM target',...
    'Contribution from the HAM-ISI vertical SRM target',...
    'Total contribution from HAM-ISI target',...
    'Location','SouthWest');
IDfig
FillPage('w')



new_spec_fig = figure;
ll=loglog(...
    freq, SRM_HAM_horz_spec,'r--',...
    freq, SRM_HAM_vert_spec,'r-.', ...
    freq, original_HAM_spec);

set(ll(1),'LineWidth',5,'Color',orange)
set(ll(2),'LineWidth',5,'Color',[0.8 0.5 0])
set(ll(3),'LineWidth',2,'Color',orange)

legend(...
    'Horizontal target for SRM HAM-ISI',...
    'Vertical target for SRM HAM-ISI',...
    'Baseline HAM-ISI spec')
xlabel('freq (Hz)')
ylabel('ASD of table motion (m/\surdHz)')
title('Revised Targets for the HAM-ISIs in the Signal Recycling Cavity','FontSize',24)
grid on
IDfig
FillPage('w')

%%
if print_figs == true
    figure(HLTS_transmission_fig)
    print -dpdf fig_HLTS_transmission.pdf
    
    figure(HSTS_transmission_fig)
    print -dpdf fig_HSTS_transmission.pdf
    
    figure(contribution_fig)
    print -dpdf fig_contributions.pdf

    figure(new_spec_fig)
    print -dpdf fig_new_HAM_spec.pdf

end    
